@@ -39,40 +39,6 @@ class ContactHandler:
 		t2 = time.clock()
 		log.info("loaded contacthandler in %s s" % round(t2-t1, 5))
 	
-	def get_numbers_from_uid(self, uid):
-		""" Returns all the numbers from a name, as a list. """
-		res = self.ab.get_contact(str(uid))
-		nrlist = {}
-		vcardlist = res.get_vcard_string().replace('\r', '').split('\n')
-		for line in vcardlist:
-			if line.startswith("TEL"):
-				nr = line.split(":")[1]
-				ltype = line.split(":")[0].split("=")
-				phonetype = "Unknown"
-				try:
-					for type in ltype:
-						rtype = type.replace(";TYPE", "")
-						if rtype != "TEL" and rtype != "VOICE":
-							phonetype = rtype	
-				except:
-					pass
-				if nr != None:
-					nrlist[nr] = phonetype
-			if line.startswith("EMAIL"):
-				nr = line.split(":")[1]
-				ltype = line.split(":")[0].split("=")
-				phonetype = "Email"
-				try:
-					for type in ltype:
-						rtype = type.replace(";TYPE", "")
-						if rtype != "EMAIL":
-							phonetype = rtype	
-				except:
-					pass
-				if nr != None:
-					nrlist[nr] = phonetype				
-		return nrlist
-
 	def get_displayname_from_uid(self, uid):
 		contact = self.ab.get_contact(str(uid))
 		if contact:
@@ -87,8 +53,6 @@ class ContactHandler:
 		chooser.hide()
 		contacts = self.osso_abook.osso_abook_contact_chooser_get_selection(c_chooser)
 		for i in self.glist(contacts):
-			get_display_name = self.osso_abook.osso_abook_contact_get_display_name
-			get_display_name.restype = ctypes.c_char_p
 			c_selector = self.osso_abook.osso_abook_contact_detail_selector_new_for_contact(c_chooser, i, 3)
 			selector = capi.pygobject_new(c_selector)
 			selector.run()
@@ -130,12 +94,17 @@ class ContactHandler:
 		
 	def glist(self, addr):
 		""" Implementation of GList. """
-		size = self.glib.g_list_length(addr)
 		class _GList(ctypes.Structure):
-			_fields_ = [('data', ctypes.c_void_p)]
-		for i in xrange(0, size):
-			item = self.glib.g_list_nth(addr, i)
-			yield _GList.from_address(item).data
+			_fields_ = [('data', ctypes.c_void_p),
+				    ('next', ctypes.c_void_p)]
+		l = addr
+		while l:
+			if type(l) == int:
+				l = _GList.from_address(l)
+			else:
+				l = _GList.from_address(l.value)
+			yield l.data
+			l = l.next
 		
 	def get_photo_from_uid(self, uid, imgsize):
 		contact = self.ab.get_contact(str(uid))
