@@ -108,9 +108,6 @@ class fMMS_controller():
 			loader.close()
 			return pixbuf
 			
-		
-	
-	
 	def convert_timeformat(self, intime, format, hideToday=False):
 		mtime = intime
 		try:
@@ -136,7 +133,6 @@ class fMMS_controller():
 		
 		return mtime
 	
-	
 	def decode_mms_from_push(self, binarydata):
 		decoder = mms_pdu.MMSDecoder()
 		wsplist = decoder.decodeCustom(binarydata)
@@ -166,7 +162,6 @@ class fMMS_controller():
 		self.save_binary_push(binarydata, trans_id)
 		return (wsplist, sndr, url, trans_id)
 	
-	
 	def save_binary_push(self, binarydata, transaction):
 		data = array.array('B')
 		for b in binarydata:
@@ -192,12 +187,10 @@ class fMMS_controller():
 	
 	def get_push_list(self, types=None):
 		return self.store.get_push_list()
-		
 	
 	def is_fetched_push_by_transid(self, transactionid):
 		return self.store.is_mms_downloaded(transactionid)
 	
-	
 	def read_push_as_list(self, transactionid):
 		return self.store.get_push_message(transactionid)
 	
@@ -237,7 +230,6 @@ class fMMS_controller():
 		log.info("returning message!")
 		return message
 	
-	
 	def is_mms_read(self, transactionid):
 		return self.store.is_message_read(transactionid)
 
@@ -245,7 +237,6 @@ class fMMS_controller():
 	def mark_mms_read(self, transactionid):
 		self.store.mark_message_read(transactionid)
 	
-	
 	def store_mms_message(self, pushid, message):
 		mmsid = self.store.insert_mms_message(pushid, message)
 		return mmsid
@@ -287,7 +278,6 @@ class fMMS_controller():
 		log.info("storing mms...%s", trans_id)
 		mmsid = self.store_mms_message(pushid, message)
 		
-		
 	def get_mms_attachments(self, transactionid, allFiles=False):
 		return self.store.get_mms_attachments(transactionid, allFiles)
 	
@@ -304,11 +294,7 @@ class fMMS_controller():
 		log.info("fullpath: %s", fullpath)
 		if os.path.isdir(fullpath):
 			log.info("starting deletion of %s", fullpath)
-			filelist = self.get_mms_attachments(fname, allFiles=True)
-			if filelist == None:
-				filelist = []
-			filelist.append("message")
-                        filelist.append("headers")
+                        filelist = os.listdir(fullpath)
                         log.info("removing: %s", filelist)
 			for fn in filelist:
 				try:
@@ -322,6 +308,7 @@ class fMMS_controller():
 			except OSError, e:
 				log.exception("failed to remove: %s %s", type(e), e)
 				raise
+		
 		self.store.delete_mms_message(fname)
 		
 	def delete_push_message(self, fname):
@@ -343,7 +330,6 @@ class fMMS_controller():
 		self.delete_mms_message(transactionid)
 		self.delete_push_message(transactionid)
 	
-
 	def validate_phonenumber_email(self, nr):
 		nr = str(nr)
 		nr = nr.replace("+", "")
@@ -353,8 +339,110 @@ class fMMS_controller():
 		else:
 		 	return False
 		
+	def get_mcc_mnc(self):
+		""" Gets the SIM cards MMC/MNC """
+		bus = dbus.SystemBus()
+		phone = dbus.Interface(bus.get_object("com.nokia.phone.SIM", "/com/nokia/phone/SIM"), "Phone.Sim")
+		hplmn = phone.read_hplmn()
+		(mcc, thirdbytes, mnc) = hplmn[0]
+		# extract 4 lowest bits (as integer)
+		mcc1 = int(mcc) & 0xF
+		# and 4 highest bits (as integer)
+		mcc2 = int(mcc) >> 4
+		# 4 lowest bits of the "united" byte is mcc3
+		mcc3 = int(thirdbytes) & 0xF
+		# 4 lowest bits of mnc is mnc1
+		mnc1 = int(mnc) & 0xF
+		# 4 highest bits of mnc is mnc2
+		mnc2 = int(mnc) >> 4
+		# if 4 highest bits of "united" byte is
+		# 0xf only 2 digits are used for mnc
+		mnc3 = int(thirdbytes) >> 4
+
+		if mnc3 == 0xf:
+			final_mnc = "%s%s" % (mnc1, mnc2)
+		else:
+			final_mnc = "%s%s%s" % (mnc1, mnc2, mnc3)
+
+		final_mcc = "%s%s%s" % (mcc1, mcc2, mcc3)
 		
+		return final_mcc, final_mnc
+
+	def get_operator_display_name(self):
+		bus = dbus.SystemBus()
+		phone = dbus.Interface(bus.get_object("com.nokia.phone.SIM", "/com/nokia/phone/SIM"), "Phone.Sim")
+		(providername, ign, ign2, err) = phone.get_service_provider_name()
+		return providername
+
+	def get_settings_from_file(self, mcc, mnc, displayname):
+		fn = open("/etc/operator_settings", 'r')
+		mcc = str(int(mcc))
+		mnc = str(int(mnc))
+		for line in fn:
+			"""
+			0 : MCC
+			1 : MNC
+			2 : SERVICE PROVIDER NAME
+			3 : ACCESS TYPE
+			4 : IAP NAME
+			5 : GPRS ACCESSPOINT NAME
+			6 : GPRS AUTOLOGIN (X = YES)
+			7 : USERNAME
+			8 : PASSWORD
+			9 : <empty>
+			10 : <empty>
+			11 : GPRS MMS/WAP GATEWAY PROXY
+			12 : GPRS MMS/WAP GATEWAY PORT
+			13 : IP ADDRESS (IF NOT FETCHED FROM SERVER)
+			14 : PRIMARY DNS ADDRESS (IF NOT FETCHED FROM SERVER)
+			15 : SECONDARY DNS ADDRESS (IF AVAILABLE)
+			16 : <empty>
+			"""
+			row = line.split('\t')
+			if row[0] == mcc and row[1] == mnc and row[3] == 'MMS' and displayname in row[2]:
+				settings = {}
+				settings['apn'] = row[5]
+				settings['user'] = row[7]
+				settings['pass'] = row[8]
+				settings['proxy'] = row[11]
+				settings['proxyport'] = row[12]
+				settings['ip'] = row[13]
+				settings['pdns'] = row[14]
+				settings['sdns'] = row[15]
+				settings['mmsc'] = row[17]
+				return settings
+		return None
+
+	def get_apn_settings_automatically(self):
+		(mcc, mnc) = self.get_mcc_mnc()
+		operatorname = self.get_operator_display_name()
+		settings = self.get_settings_from_file(mcc, mnc, operatorname)
+		
+		if self.are_we_tele2_se(mcc, mnc, operatorname):
+			settings = self.are_we_tele2_se(mcc, mnc, operatorname)
+		
+		log.info("Settings loaded automatically. MCC: %s MNC: %s Operatorname: %s" % (mcc, mnc, operatorname))
+		log.info("Settings loaded automatically: %s" % settings)
+		return settings
 	
+	def are_we_tele2_se(self, mcc, mnc, operatorname):
+		mcc = str(int(mcc))
+		mnc = str(int(mnc))
+		if mcc == "240" and mnc == "7":
+			if operatorname == "Tele2" or operatorname == "Comviq":
+				settings = {}
+				settings['apn'] = "internet.tele2.se"
+				settings['user'] = ""
+				settings['pass'] = ""
+				settings['proxy'] = "130.244.202.30"
+				settings['proxyport'] = "8080"
+				settings['mmsc'] = "http://mmsc.tele2.se"
+				settings['pdns'] = "0.0.0.0"
+				settings['sdns'] = "0.0.0.0"
+				settings['ip'] = "0.0.0.0"
+				return settings
+		return False
+
+
 if __name__ == '__main__':
-	c = fMMS_controller()
-	pass
\ No newline at end of file
+	c = fMMS_controller()
\ No newline at end of file
